summaryrefslogtreecommitdiff
path: root/src/precompiled.hpp
diff options
context:
space:
mode:
authorMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:01:47 +0900
committerMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:01:47 +0900
commit4a7aad06d95701cf232198093ce396dcdbb53e5b (patch)
tree8ced8929e603a179d9434099244dfd782e705d5e /src/precompiled.hpp
parent1fc63e4dbcf1438eb571d720f57be68852f820f7 (diff)
ZeroMQ renamed to Crossroads
Signed-off-by: Martin Sustrik <sustrik@250bpm.com>
Diffstat (limited to 'src/precompiled.hpp')
-rw-r--r--src/precompiled.hpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/precompiled.hpp b/src/precompiled.hpp
index aeea3cd..93f5ee6 100644
--- a/src/precompiled.hpp
+++ b/src/precompiled.hpp
@@ -1,15 +1,15 @@
/*
- Copyright (c) 2011 250bpm s.r.o.
+ Copyright (c) 2011-2012 250bpm s.r.o.
Copyright (c) 2011 Other contributors as noted in the AUTHORS file
- This file is part of 0MQ.
+ This file is part of Crossroads project.
- 0MQ is free software; you can redistribute it and/or modify it under
+ Crossroads is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
- 0MQ is distributed in the hope that it will be useful,
+ Crossroads is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.
@@ -18,8 +18,8 @@
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef __ZMQ_PRECOMPILED_HPP_INCLUDED__
-#define __ZMQ_PRECOMPILED_HPP_INCLUDED__
+#ifndef __XS_PRECOMPILED_HPP_INCLUDED__
+#define __XS_PRECOMPILED_HPP_INCLUDED__
#ifdef _MSC_VER
@@ -39,8 +39,8 @@
#include <string>
#include <vector>
// 0MQ definitions and exported functions
#include "../include/zmq.h"
#endif // _MSC_VER
@@ -39,8 +39,8 @@
#include <string>
#include <vector>
-// 0MQ definitions and exported functions
-#include "../include/zmq.h"
+// Crossroads definitions and exported functions
+#include "../include/xs.h"
#endif // _MSC_VER